summaryrefslogtreecommitdiffstats
path: root/quanta/treeviews/templatestreeview.h
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/treeviews/templatestreeview.h')
-rw-r--r--quanta/treeviews/templatestreeview.h32
1 files changed, 16 insertions, 16 deletions
diff --git a/quanta/treeviews/templatestreeview.h b/quanta/treeviews/templatestreeview.h
index c0df69e5..7816cffd 100644
--- a/quanta/treeviews/templatestreeview.h
+++ b/quanta/treeviews/templatestreeview.h
@@ -28,7 +28,7 @@ class TemplatesTreeBranch : public BaseTreeBranch {
public:
TemplatesTreeBranch(KFileTreeView *parent, const KURL& url,
- const QString& name, const QPixmap& pix,
+ const TQString& name, const TQPixmap& pix,
bool showHidden = false, KFileTreeViewItem *branchRoot = 0L);
/** read the mimetype */
@@ -57,9 +57,9 @@ public:
~TemplatesTreeView();
/** Writes a .dirinfo file from the selected item's path */
- bool writeDirInfo(const QString& dirInfoFile = QString::null);
+ bool writeDirInfo(const TQString& dirInfoFile = TQString::null);
/** Reads a .dirinfo file from the selected item's path */
- DirInfo readDirInfo(const QString& dir = QString::null);
+ DirInfo readDirInfo(const TQString& dir = TQString::null);
public slots:
@@ -75,12 +75,12 @@ public slots:
*
* @param listView KListView where the event comes from
*
* @param item QListViewItem where the mousepointer is hovering
*
* @param point QPoint coordinates of the event
*
*/
- void slotMenu(KListView *listView, QListViewItem *item, const QPoint &point);
+ void slotMenu(KListView *listView, TQListViewItem *item, const TQPoint &point);
/** Creates a new document based in the selected template. */
void slotNewDocument();
/** Insert the template as text, image, new document. */
@@ -90,7 +90,7 @@ public slots:
/** No descriptions */
void slotNewDir();
/** Handles dropping on the document from the template tree */
- void slotDragInsert(QDropEvent *);
+ void slotDragInsert(TQDropEvent *);
/**
* slot for the RBM
@@ -99,7 +99,7 @@ public slots:
*/
void slotSendInMail();
void slotUploadTemplate();
- virtual void slotSelectFile(QListViewItem *item);
+ virtual void slotSelectFile(TQListViewItem *item);
void slotOpen();
void slotPaste();
void slotDelete();
@@ -110,7 +110,7 @@ public slots:
void slotInsertTag();
/** Sets the project template directory */
- void slotNewProjectLoaded(const QString &, const KURL &, const KURL &);
+ void slotNewProjectLoaded(const TQString &, const KURL &, const KURL &);
private:
@@ -123,7 +123,7 @@ private:
template file */
KURL filterTemplate();
void writeTemplateInfo();
- void updateTypeDescription(KFileTreeViewItem *item, const QString &typeString);
+ void updateTypeDescription(KFileTreeViewItem *item, const TQString &typeString);
BaseTreeBranch *m_projectDir;
int m_deleteMenuId;
@@ -131,7 +131,7 @@ private:
int m_reloadMenuId;
int m_downloadMenuId;
QuantaPropertiesPage *m_quantaProperties;
- QString m_projectName;
+ TQString m_projectName;
KURL localURL;
KURL globalURL;
KPopupMenu *m_fileMenu;
@@ -148,15 +148,15 @@ private:
signals: // Signals
void insertFile(const KURL &);
void downloadTemplate();
- void uploadTemplate(const QString&);
+ void uploadTemplate(const TQString&);
protected: // Protected methods
KFileTreeBranch* newBranch(const KURL& url);
- virtual QDragObject * dragObject();
+ virtual TQDragObject * dragObject();
// virtual void startDrag();
- void contentsDropEvent(QDropEvent *event);
- bool acceptDrag(QDropEvent* e ) const;
- QString createTemplateTarball();
+ void contentsDropEvent(TQDropEvent *event);
+ bool acceptDrag(TQDropEvent* e ) const;
+ TQString createTemplateTarball();
};
#endif
@@ -75,12 +75,12 @@ public slots:
* @param listView KListView where the event comes from
*
- * @param item QListViewItem where the mousepointer is hovering
+ * @param item TQListViewItem where the mousepointer is hovering
*
@@ -75,12 +75,12 @@ public slots:
*
- * @param point QPoint coordinates of the event
+ * @param point TQPoint coordinates of the event
*
*/